@@ -57,7 +57,7 @@
 }
 @end
 
-@interface GormDocument : NSDocument <IBDocuments, GSNibContainer, NSCoding>
+@interface GormDocument : NSDocument <IBDocuments, GSNibContainer, NSCoding> 
 {
   GormClassManager      *classManager;
   GormFilesOwner	*filesOwner;
@@ -205,6 +205,12 @@
  */
 - (NSArray *) allManagedPboardTypes;
 
+/**
+ * Open the editor for anObject, with parent object.
+ */
+- (id<IBEditors>) openEditorForObject: (id)anObject
+                     withParentObject: (id)parentObj;
+
 /* Language translation */
 - (void) translate: (id)sender;
 - (void) exportStrings: (id)sender;
@@ -283,6 +289,16 @@
  */
 - (NSMenu *) servicesMenu;
 
+/**
+ * Set the font menu.
+ */
+- (void) setFontMenu: (NSMenu *)menu;
+
+/**
+ * Returns the font menu for the document.
+ */
+- (NSMenu *) fontMenu;
+
 /**
  * Sets the windows menu.
  */
@@ -423,6 +439,26 @@
  * Reactivate all of the editors...
  */
 - (void) reactivateEditors;
+
+/**
+ * Returns the name for the object...
+ */ 
+- (NSString*) nameForObject: (id)anObject;
+
+/**
+ * Returns the object for name.
+ */
+- (id) objectForName: (NSString*)name;
+
+/**
+ * Returns all names for all objects known to Gorm.
+ */
+- (NSArray *) objects;
+
+/**
+ * Add aConnector to the set of connectors in this document.
+ */ 
+- (void) addConnector: (id<IBConnectors>)aConnector;
 @end
 
 @interface GormDocument (MenuValidation)
