@@ -25,7 +25,8 @@
 #ifndef INCLUDED_IBDOCUMENTS_H
 #define INCLUDED_IBDOCUMENTS_H
 
-#include <Foundation/NSGeometry.h>
+#include <Foundation/Foundation.h>
+
 #include <InterfaceBuilder/IBEditors.h>
 #include <InterfaceBuilder/IBConnectors.h>
 #include <InterfaceBuilder/IBSystem.h>
@@ -46,6 +47,12 @@ IB_EXTERN NSString *IBWillCloseDocumentNotification;
  */
 - (NSArray*) allConnectors;
 
+/**
+ * Attach object to document with a specified name.  Pass nil to
+ * aName to have Gorm assign a name to it.  (GS extension)
+ */ 
+- (void) attachObject: (id)anObject toParent: (id)aParent withName: (NSString *)aName;
+
 /**
  * Attaches an object to the document and makes the association
  * with the parent.
@@ -113,11 +120,21 @@ IB_EXTERN NSString *IBWillCloseDocumentNotification;
  */
 - (void) detachObject: (id)anObject;
 
+/**
+ * Detaches an object from the receiver, closes editor if asked.  GNUstep extension.
+ */
+- (void) detachObject: (id)anObject closeEditor: (BOOL)close_editor;
+
 /**
  * Detaches an array of objects from the receiver.
  */
 - (void) detachObjects: (NSArray*)anArray;
 
+/**
+ * Detaches an array of objects from the receiver. Closes editor if asked. GNUstep extension.
+ */
+- (void) detachObjects: (id)anObject closeEditors: (BOOL)close_editor;
+
 /**
  * The path of the file which represents the document.
  */
